pub trait Optimizable {
type Inputs;
type Targets;
// Required method
fn compute_grad(
&self,
params: &[f64],
inputs: &Self::Inputs,
targets: &Self::Targets,
) -> (f64, Vec<f64>);
}Expand description
Trait for models which can be gradient-optimized.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
Sourceimpl Optimizable for BaseLogisticRegressor
Computing the gradient of the underlying Logistic
Regression model.
impl Optimizable for BaseLogisticRegressor
Computing the gradient of the underlying Logistic Regression model.
The gradient is given by
XT(h(Xb) - y) / m
where h is the sigmoid function and b the underlying model parameters.