Module cost_fn

Module cost_fn 

Cost Functions.

This module contains a number of structs implementing the CostFunc trait.

These structs are used within Neural Networks and Generalized Linear Regression (not yet implemented).

You can also create your own custom cost functions for use in your models. Just create a struct implementing the CostFunc trait.

Structs

CrossEntropyError
The cross entropy error cost function.
MeanSqError
The mean squared error cost function.

Traits

CostFunc
Trait for cost functions in models.