Module transforms

Module transforms 

The Transforms module

This module contains the Transformer and Invertible traits and reexports the transformers from child modules.

The Transformer trait provides a shared interface for all of the data preprocessing transformations in rusty-machine.

The transformers provide preprocessing transformations which are commonly used in machine learning.

Re-exports

pub use self::minmax::MinMaxScaler;
pub use self::shuffle::Shuffler;
pub use self::standardize::Standardizer;

Modules

minmax
The Min-Max transformer
shuffle
The Shuffler
standardize
The Standardizing Transformer

Traits

Invertible
Trait for invertible data transformers
Transformer
Trait for data transformers