Cost Functions.
This module contains a number of structs implementing the CostFunc trait.
These structs are used within Neural Networks and Generalized Linear Regression (not yet implemented).
You can also create your own custom cost functions for use in your models.
Just create a struct implementing the CostFunc trait.
Structs
- Cross
Entropy Error - The cross entropy error cost function.
- Mean
SqError - The mean squared error cost function.
Traits
- Cost
Func - Trait for cost functions in models.